// @flow

import React from 'react'
import { themr } from 'react-css-themr'
import cn from 'classnames'
import Hero from 'components/Hero'

export const defaultStyles = {
  title: 'f3 f1-ns mw8 center lh-title fw9 tc',
  author: 'f5 f4-ns fw6 center',
  body: 'mw7 center mt3 mt4-ns pa3 pa3-ns',
}

const Article = ({
  post,
  theme,
}: {
  post: TPost,
  theme: { [key: string]: string },
}) => {
  const {
    title,
    author,
    overlayColor = 'rgba(0, 0, 0, 0)',
    image,
    smallImage,
    body,
  } = post

  const postTheme = post.theme || {}
  const overrideTheme = {
    root: cn(theme.header, postTheme.header) || undefined,
    container: cn(theme.headerContainer, postTheme.headerContainer) || undefined,
  }

  return (
    <article data-component="Article">
      <Hero
        title={title}
        subtitle={author}
        overlayColor={overlayColor}
        image={image}
        smallImage={smallImage}
        overrideTheme={overrideTheme}
      >
        <div className={cn(theme.headerWrapper, postTheme.headerWrapper)}>
          <h1 className={cn(theme.title, postTheme.title)}>
            {title}
          </h1>
          <h2 className={cn(theme.subtitle, postTheme.subtitle)}>
            {author}
          </h2>
        </div>
      </Hero>
      <div
        className={cn('markdown content', theme.body)}
        dangerouslySetInnerHTML={{ __html: body }}
      />
    </article>
  )
}

export default themr('Article', {}, { composeTheme: 'softly' })(Article)
