// @flow

import React from 'react'
import merge from 'lodash.merge'
import { themr } from 'react-css-themr'
import cn from 'classnames'
import Icon from 'components/Icon'

export const defaultStyles = {
  root: '',
  image: '',
  name: '',
  from: '',
  content: '',
}

const CustomerReviewListItem = ({
  item: { icon, image, name, from, content },
  className,
  theme,
  overrideTheme,
}: {
  item: TCustomerReview,
  className?: string,
  theme: { [key: string]: string },
  overrideTheme: { [key: string]: string },
}) => {
  const _theme = merge(theme, overrideTheme)
  return (
    <div
      data-component="CustomerReviewListItem"
      className={cn('flex items-center', _theme.root, className)}
    >
      {icon && (
        <div className={_theme.icon}>
          <Icon name={icon} />
        </div>
      )}
      <div className={_theme.meta}>
        <div className={_theme.imageWrapper}>
          <img className={_theme.image} src={image} alt={name} />
        </div>
        <div className={_theme.nameWrapper}>
          <div className={_theme.name}>{name}</div>
          <div className={_theme.from}>{from}</div>
        </div>
      </div>
      <div className={_theme.content}>{content}</div>
    </div>
  )
}

CustomerReviewListItem.defaultProps = {
  className: null,
}

export default themr('CustomerReviewListItem', {}, { composeTheme: 'softly' })(CustomerReviewListItem)
