// @flow

import React from 'react'
import { themr } from 'react-css-themr'
import cn from 'classnames'
import Icon from 'components/Icon'
import Link from 'components/Link'

const Footer = ({
  data: {
    title,
    subtitle,
    phone,
    email,
    contact,
    items = [],
  } = {},
  theme,
  className,
}: {
  data: {
    title: string,
    subtitle: string,
    phone: string,
    email: string,
    contact: {
      name: string,
      address: string,
      phone: string,
      email: string,
    },
    items: Array<{
      to: string,
      label: any,
    }>,
  },
  className?: string,
  theme: { [key: string]: string },
}) => (
  <div
    data-component="Footer"
    className={cn(theme.root, className)}
  >
    <div className={theme.title}>{title}</div>
    <div className={theme.subtitle}>{subtitle}</div>
    <div className={theme.phoneWrapper}>
      <a className={cn('dib link', theme.phone)} href={`tel:${phone}`}>
        <Icon className={theme.icon} name="fa-phone" />
        {phone}
      </a>
    </div>
    <div className={theme.emailWrapper}>
      <a className={cn('dib link', theme.email)} href={`mailto:${email}`}>
        <Icon className={theme.icon} name="fa-envelope-o" />
        {email}
      </a>
    </div>
    <div className="flex flex-wrap">
      <div className="w-100 w-third-ns">
        <div className={theme.header}>Thông tin liên hệ</div>
        <div className={theme.item}>{contact.name}</div>
        <div className={theme.item}>{contact.address}</div>
        <div className={theme.item}>{contact.phone}</div>
        <div className={theme.item}>{contact.email}</div>
      </div>
      <div className="w-100 w-third-ns">
        <div className={theme.header}>Sitemap</div>
        {items.map(item => (
          <Link key={item.to} className={cn(theme.item, theme.link)} to={item.to}>
            {item.label}
          </Link>
        ))}
      </div>
      <div className="w-100 w-third-ns">
        <div className={theme.header}>Google Map</div>
      </div>
    </div>
  </div>
)

Footer.defaultProps = {
  className: undefined,
}

export default themr('Footer', {}, { composeTheme: 'softly' })(Footer)
