// @flow

import React from 'react'
import { themr } from 'react-css-themr'
import { compose, withState } from 'recompose'
import cn from 'classnames'
import Lightbox from 'react-images'

const Gallery = ({
  images,
  selected,
  select,
  isOpen,
  open,
  className,
  theme,
}: {
  images: Array<{
    src: string,
    srcset: Array<string>,
    caption?: string,
  }>,
  selected: number,
  select: (selected: number) => void,
  isOpen: boolean,
  open: (isLightboxOpene: boolean) => void,
  className?: string,
  theme: { [key: string]: string },
}) => (
  <div
    data-component="Gallery"
    className={cn(theme.root, className)}
  >
    {images.map(({ src, caption }, idx) => (
      <div key={src} className="w-50 w-third-ns w-25-l pa1">
        <div className="relative aspect-ratio--16x9 overflow-y-hidden grow">
          <img
            className="absolute pointer"
            onClick={() => {
              open(true)
              select(idx)
            }}
            key={src}
            src={src}
            alt={caption}
          />
        </div>
      </div>
    ))}
    <Lightbox
      currentImage={selected}
      images={images}
      isOpen={isOpen}
      onClickPrev={() => {
        select(selected - 1 < 0 ? selected : selected - 1)
      }}
      onClickNext={() => {
        select(selected + 1 >= images.length ? 0 : selected + 1)
      }}
      onClose={() => open(false)}
    />
  </div>
)

Gallery.defaultProps = {
  className: undefined,
}

export default compose(
  themr('Gallery', {}, { composeTheme: 'softly' }),
  withState('selected', 'select', 0),
  withState('isOpen', 'open', false),
)(Gallery)
