// @flow

import React from 'react'
import { themr } from 'react-css-themr'
import { compose, withState } from 'recompose'
import cn from 'classnames'
import Icon from 'components/Icon'
import Link from 'components/Link'

export const defaultStyles = {
  root: '',
  item: 'ttu f6',
}

const LanguageSelector = ({
  isShow,
  show,
  theme,
  className,
  items = [],
  selected,
  isSticky,
}: {
  isShow: boolean,
  show: (isShow: boolean) => void,
  items: Array<{
    lang: string,
    to: string,
  }>,
  selected: string,
  isSticky: boolean,
  className?: string,
  theme: { [key: string]: string },
}) => (
  <div
    data-component="LanguageSelector"
    className={cn('pointer flex items-center', theme.root, className)}
    onClick={() => show(!isShow)}
  >
    <Icon name="fa-globe" className={theme.icon} />
    {items.map(item => (
      <Link
        key={item.lang}
        to={item.to}
        className={isSticky
          ? cn(theme.stickyItem || theme.item, theme.stickyLink || theme.link, {
            [theme.stickySelected]: selected === item.lang,
          })
          : cn(theme.item, theme.link, {
            [theme.selected]: selected === item.lang,
          })
        }
      >
        {item.lang}
      </Link>
    ))}
  </div>
)

LanguageSelector.defaultProps = {
  className: undefined,
}

export default compose(
  themr('LanguageSelector', {}, { composeTheme: 'softly' }),
  withState('isShow', 'show', false),
)(LanguageSelector)
