// @flow

import React from 'react'
import { themr } from 'react-css-themr'
import cn from 'classnames'
import LanguageSelector from 'components/LanguageSelector'
import Logo from 'components/Logo'
import Link from 'components/Link'
import Icon from 'components/Icon'

export const defaultStyles = {
  root: 'roboto-condensed',
  item: 'pl3 f4 black-70 hover-black-90',
}

const Navigation = ({
  logo,
  items,
  language,
  languages = [],
  className,
  theme,
  show,
  isShow,
  isSticky,
}: {
  logo?: any,
  items: Array<{
    to: string,
    label: any,
  }>,
  language: string,
  languages: Array<{
    lang: string,
    link: string,
  }>,
  className?: string,
  theme: { [key: string]: string },
  show: (isShow: boolean) => void,
  isShow: boolean,
  isSticky: boolean,
}) => (
  <div
    data-component="Navigation"
    className={cn('flex items-center justify-between', className, theme.root)}
  >
    <Link className="dn db-l flex-none" to="/">
      <Logo>{logo}</Logo>
    </Link>
    <div className="flex-l items-center dn db-l">
      {items.map(item => (
        <Link
          key={item.to}
          className={isSticky
            ? cn(theme.stickyItem || theme.item, theme.stickyLink || theme.link)
            : cn(theme.item, theme.link)
          }
          {...item}
        >
          {item.label}
        </Link>
      ))}
      {languages.length > 0 && <span className={isSticky ? theme.stickyItem : theme.item}>|</span>}
      {languages.length > 0 && (
        <LanguageSelector
          className={isSticky ? theme.stickyItem : theme.item}
          selected={language}
          items={languages}
          isSticky={isSticky}
        />
      )}
    </div>
    <div className="dn-l flex items-center justify-between w-100">
      <Icon
        name={isShow ? 'fa-times' : 'fa-bars'}
        className={theme.menuItem}
        onClick={() => show(!isShow)}
      />
      <Link className="flex-none" to="/">
        <Logo>{logo}</Logo>
      </Link>
      <Icon name="fa-search" className={theme.menuItem} />
    </div>
  </div>
)

Navigation.defaultProps = {
  className: undefined,
  logo: 'Your Logo',
}

export default themr('Navigation', {}, { composeTheme: 'softly' })(Navigation)
