// @flow

import React from 'react'
import { themr } from 'react-css-themr'
import cn from 'classnames'
import SectionData from 'components/SectionData'

export const defaultStyles = {
  root: '',
  title: '',
  subtitle: '',
  body: 'mw8 center',
  itemWrapper: 'w-100 w-third-ns pv2 ph2-ns',
  action: '',
}

const SectionWithData = ({
  section: {
    title,
    subtitle,
    type,
    useH1 = false,
    data = [],
    actions = [],
    backgroundImage,
  } = {},
  theme,
  childrenTheme,
  Link,
  className,
}: {
  section?: TSection,
  theme: { [key: string]: string },
  childrenTheme: { [key: string]: string },
  Link: any,
  className?: string,
}) => {
  const H = useH1 ? 'h1' : 'div'

  const style = backgroundImage ? {
    backgroundImage: `url(${backgroundImage})`,
  } : {}

  return (
    <div
      data-component="SectionWithData"
      className={cn(theme.root, className)}
      style={style}
    >
      <H className={theme.title}>{title}</H>
      <div className={theme.subtitle}>{subtitle}</div>
      <SectionData
        type={type}
        className={theme.body}
        itemClassName={theme.itemWrapper}
        childrenTheme={childrenTheme}
        data={data}
        Link={Link}
      />
      <div className={theme.footer}>
        {actions.length > 0 && actions.map(action => (
          <div className="h3 tc mt2 mt3-ns">
            <Link
              className={cn('button', theme.action)}
              to={action.href}
            >
              {action.label}
            </Link>
          </div>
        ))}
      </div>
    </div>
  )
}

SectionWithData.defaultProps = {
  callToAction: null,
  className: null,
  section: {},
}

export default themr('SectionWithData', {}, { composeTheme: 'softly' })(SectionWithData)
