// @flow

import React from 'react'
import { storiesOf } from '@kadira/storybook'
import Sections from './'
import themes from './sample-data/themes.yml'
import connectedThemes from './sample-data/connected-themes.yml'
import { sections } from './sample-data/sections.yml'
import { sections as connectedSections } from './sample-data/connected-sections.yml'

const Link = ({ to, children, className }: {
  to: string,
  children: any,
  className?: string,
}) => (
  <a className={className} href={to}>{children}</a>
)

Link.defaultProps = {
  className: null,
}

const image = '//res.cloudinary.com/connected/image/upload/c_scale,w_1920/v1495113627/workspace-laptop_hjhtpb.jpg'
const video = 'https://connected.com.vn/dd1c6332a2f4fc69779b57f13e806fa5.mp4'

storiesOf('Sections', module)
  .add('default', () => (
    <Sections themes={themes} sections={sections} Link={Link} />
  ))
  .add('Connected', () => (
    <div>
      <div className="relative dn db-l aspect-ratio--16x9">
        <div className="absolute absolute--fill z-1 flex flex-column items-center justify-center mw7 center tc">
          <h1 className="f1">Shortcut to Your Digital Success</h1>
          <div className="f4">Connected is a young team that is passionate about digital marketing. We are here to help you find the best solutions to dominate your market.</div>
        </div>
        <video
          className="absolute z-0 w-100"
          playsInline
          autoPlay
          muted
          loop
          poster={image}
        >
          <source src={video} type="video/mp4" />
        </video>
      </div>
      <div className="relative dn-l vh-100">
        <div className="absolute absolute--fill z-1 flex flex-column items-center justify-center mw7 center tc">
          <h1 className="f1">Shortcut to Your Digital Success</h1>
          <div className="f4">Connected is a young team that is passionate about digital marketing. We are here to help you find the best solutions to dominate your market.</div>
        </div>
      </div>
      <Sections themes={connectedThemes} sections={connectedSections} Link={Link} />
    </div>
  ))
