// @flow

function createFormReducer({
  ON_CHANGE,
  validateField,
}: {
  ON_CHANGE: string,
  validateField: Function,
}) {
  return function reducer(
    state: any = { error: {} },
    action: { type: string, payload: { name: string, value: string } },
  ) {
    const { name, value } = action.payload

    const error = {
      ...state.error,
      [name]: validateField(name, value),
    }

    const keys = Object.keys(error)
    const isValid = keys.map(key => error[key]).filter(x => !!x).length === 0

    switch (action.type) {
      case ON_CHANGE:
        return {
          ...state,
          [name]: value,
          error,
          isValid,
        }
      default:
        return state
    }
  }
}

export default createFormReducer
